<?php
/**
 * @package     Joomla.Site
 * @subpackage  mod_banners
 *
 * @copyright   Copyright (C) 2005 - 2015 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

/**
 * Helper for mod_banners
 *
 * @package     Joomla.Site
 * @subpackage  mod_banners
 * @since       1.5
 */
class joomla_banners
{
	/**
	 * Retrieve list of banners
	 *
	 * @param   \Joomla\Registry\Registry  &$params  module parameters
	 *
	 * @return  mixed
	 */
	public static function &getList(&$params)
	{
		
				$cats = json_decode($params->get('joomla_banners_categories_limit', ''));
				$show_featured = $params->get('joomla_banners_pinned', '');
				$order = $params->get('joomla_banners_ordering', 'name DESC');	
				$count = $params->get('j_banners_count', '5');
				
			
			
				// Cast object to an array
				$catitems = (array)$cats;
				
				// Get catids from array
				$catids = array_keys($catitems);
				
				// Count number of cats to process
				$limitcount = count($catitems);
				
				
		
				// If just a single value then proceed as usual
				if($limitcount <= 1) {
				
					// If no limits on category numbers we just perform the standard query
					$db = JFactory::getDBO();
					$query	= $db->getQuery(true);
					$query->select('a.*');
					$query->from('#__banners AS a'); 
					
					if(!empty($catids)) {
						$query->where('a.catid in (' . implode(',', $catids) . ')');
					    $query->where('a.state = 1');
					}
					
					// Featured
					if($show_featured == 0) {
						$query->where('a.sticky = 0');
					} elseif($show_featured == 1) {
						$query->where('a.sticky = 1');
					} 
					
					$query->where('state = 1');
					
					
					if(isset($catids[0])) {
						$limit = $cats->{$catids[0]};
						
						if($limit > $count) {
							$limit = $count;
						}
						
						if($limit == "") {
							$limit = $count;
						}
						
					} else {
						$limit = $count;
						
					}
					
					if($order =='title') {
						
						$query->order('name ASC');
						
					} elseif($order =='title_reverse') {
						
						$query->order('name DESC');
						
					} elseif($order =='random') {
					
						$query->order('RAND()');
						
					} elseif($order =='order') {
					
						$query->order('ordering ASC');
					
					} elseif($order =='order_reverse') {
					
						$query->order('ordering DESC');
					
					} 
		
			
					$db->setQuery($query, 0, $limit);
					$banners = $db->loadObjectList();
					
				} else {
				
					// Get items from each category limited by number set in admin
					// To do this we need to union the selects
					// and then apply an order at the end
					
					$db = JFactory::getDbo();
					$query = $db->getQuery(true);
					
					// Loops through the catd ids and limits set
					// catid:limit
					// 42:2
				
					// We need to calculate the new total items to display
					// Check later to see if it's higher or lower than the count amount
					$total = '';
				
					foreach ($cats as $catid => $limit) {
						
						
						// If limit is left blank in the settings
						if($limit == "") {
							$limit = $count;
						}
						
						// Set up the union query
						${'q'.$catid} = $db->getQuery(true);
						
						// Create the select for each cat
						${'q'.$catid}
						    ->select('*')
						    ->from('#__banners')
						   	->where('state = 1')
						    ->where('catid = '.$catid.'');
						    
						    if($order =='title') {
						    	${'q'.$catid}->order('name ASC');
						    } elseif($order =='title_reverse') {
						    	${'q'.$catid}->order('name DESC');
						    } elseif($order =='random') {
						    	${'q'.$catid}->order('RAND()');
						    } elseif($order =='order') {
						    	${'q'.$catid}->order('ordering ASC');
						    } elseif($order =='order_reverse') {
						    	${'q'.$catid}->order('ordering DESC');
						    } 
						   
						   // Featured items
						    if($show_featured == 0) {
						    	${'q'.$catid}->where('sticky = 0');
						    } elseif($show_featured == 1) {
						    	${'q'.$catid}->where('sticky = 1');
						    } 
						    
						    // Limit the items from this category
						    ${'q'.$catid}->setLimit($limit);
						    
						    $total += $limit;
					}
							
					// Perform the base query
					// First item is a dummy
					// Then loop through the unions
					// created in the previous step
					
					$query
					    ->select('*')
					    ->from('#__banners')
					    ->where('1 = 0');
					    
					 foreach ($cats as $catid => $limit) {
					   	$query->union(${'q'.$catid});
					 }
					 
					 if($order =='title') {
					 	
					 	//$query->order('name ASC');
					 	$query .= ' ORDER BY name ASC ';
					 	
					 } elseif($order =='title_reverse') {
					 	
					 	//$query->order('name DESC');
					 	$query .= ' ORDER BY name DESC ';
					 	
					 } elseif($order =='random') {
					 
					 	//$query->order('RAND()');
					 	$query .= ' ORDER BY RAND() ';
					 	
					 } elseif($order =='order') {
					 
					 	//$query->order('ordering ASC');
					 	$query .= ' ORDER BY ordering ASC ';
					 
					 } elseif($order =='order_reverse') {
					 
					 	//$query->order('ordering DESC');
					 	$query .= ' ORDER BY ordering DESC ';
					 
					 } 
					 
					 
				
				
				    // If the total number of items is less than the count
				    if($total < $count) {
				    	$query .= ' LIMIT ' . $total ;
				    } else {
				    	$query .= ' LIMIT  ' . $count ;
				    }
				    // Set the query
				    $db->setQuery($query);	
					
					// The final array    	    	    
				    $banners = $db->setQuery($query)->loadObjectList();	
							
				}
		
		if(is_array($banners)) {
			foreach ($banners as $key => $banner) {
					
					// Create the new class
					$item = new stdClass();
					
					// Images
					$image = json_decode($banner->params);
					$item->image = $image->imageurl;
					
					// Title
					$item->title = $banner->name;
					
					// Text
					$item->introtext = $banner->description;
					
					// Link
					$item->link = $banner->clickurl;
					
					// Category
					$category = self::get_contact_cat($banner->catid); 
					$item->category = $category[0]->title;
					$item->category_alias = $category[0]->alias; 
					$item->catlink = 'index.php?option=com_contact&view=category&id='.$banner->catid;
					
					
					// Impresions and clicks
					$item->impressions = $banner->impmade;
					$item->clicks = $banner->clicks;
					
					// Client
					if($banner->cid) {
						$client = self::get_client($banner->cid);
						$item->client = $client[0]->name;
						$item->client_alias = strtolower(str_replace(' ', '-', $item->client));
					} else {
						$item->client = false;
						$item->client_alias = false;
					}	
					
					$item->date = $banner->created;
					$item->publishdate = $banner->publish_up;
					
					// Tags that should be nulled
					$item->tags = false;
					$item->created= false;
					$item->catlink = false;
					$item->featured = 0;
					$item->newlink = 0;
					//$item->$id = false;
					$item->video =false;
					$item->authorLink=false;
					$item->author=false;
					$item->avatar=false;
					$item->tagblock=false;
					
					$item->rating="";
					$item->fulltext = false;
					
					$items[] = $item;
			}
			
			return $items;
		}
	}
	
	public static function get_contact_cat($category) {
		$db = JFactory::getDbo(); 
		$query = $db->getQuery(true); 
		$query->select(array('title', 'alias')) 
		      ->from($db->quoteName('#__categories')) 
			  ->setLimit(1)
			  ->where($db->quoteName('id') . ' = '. $category);
		$db->setQuery($query); 
		$rows = $db->loadObjectList();
		return $rows;
	}
	
	public static function get_client($category) {
		$db = JFactory::getDbo(); 
		$query = $db->getQuery(true); 
		$query->select(array('name')) 
		      ->from($db->quoteName('#__banner_clients')) 
			  ->setLimit(1)
			  ->where($db->quoteName('id') . ' = '. $category);
		$db->setQuery($query); 
		$rows = $db->loadObjectList();
		return $rows;
	}
}
