<?php
/**
 * @version		$Id: helper.php 1832 2013-01-30 13:05:12Z lefteris.kavadas $
 * @package		K2
 * @author		JoomlaWorks http://www.joomlaworks.net
 * @copyright	Copyright (c) 2006 - 2013 JoomlaWorks Ltd. All rights reserved.
 * @license		GNU/GPL license: http://www.gnu.org/copyleft/gpl.html
 */

// no direct access
defined('_JEXEC') or die;

class k2_categories
{

	public static function getList(&$params, $format = 'html')
	{

		$cats = json_decode($params->get('k2_categories_limit', ''));
		$order = $params->get('k2_categories_ordering', 'name DESC');	
		$count = $params->get('k2_cat_count', '5');
				
			
		// Cast object to an array
		$catitems = (array)$cats;
		
		// Get catids from array
		$catids = array_keys($catitems);
		
		// Count number of cats to process
		$limitcount = count($catitems);
		
		// Get view access levels for current user id
		$user = JFactory::getUser();
		$viewLevels = JAccess::getAuthorisedViewLevels(JUserHelper::getUserId($user->username));
		$access_levels = implode(",", $viewLevels);	
		
		// Link Type
		$link_type = $params->get('k2cat_link_type', 'item');
		$link_fallback = $params->get('k2cat_link_fallback');
		
		// If no limits on category numbers we just perform the standard query
		$db = JFactory::getDBO();
		$query	= $db->getQuery(true);
		$query->select('a.*');
		$query->from('#__k2_categories AS a'); 
		
		if(!empty($catids)) {
			$query->where('a.id in (' . implode(',', $catids) . ')');
		    $query->where('a.published = 1');
		}
		
		$query->where('published = 1');
		$query->where("access in ($access_levels)");
		
		if($order =='title') {
			$query->order('name ASC');
		} elseif($order =='title_reverse') {
			$query->order('name DESC');
		} elseif($order =='random') {
			$query->order('RAND()');
		} elseif($order =='order') {
			$query->order('ordering ASC');
		} elseif($order =='order_reverse') {
			$query->order('ordering DESC');
		} 

		$db->setQuery($query, 0, $count);
		$categories = $db->loadObjectList();
			
		// Manual Links
		$manual_links = null;
		
		if($link_type =="manual") {
			$manual_links = explode(PHP_EOL, $params->get('k2cat_manual_links'));
		}

		if(is_array($categories)) {
			foreach ($categories as $key=>$cat)
			{
			
				// Create the new class
				$item = new stdClass();
										
				// Store the image name
				if($cat->image !=="") {
					$item->image = 'media/k2/categories/' . $cat->image;
				} else {
					$item->image = "";
				}
				
				// Item Title
				$item->title = $cat->name;
				
				// Item Text
				$item->introtext = $cat->description;
				
				if($link_type =="manual") {
					
					if(isset($manual_links[$key])) {
						$item->link = $manual_links[$key];
					}  else {
						if($link_fallback) {
								$item->link = "index.php?option=com_k2&view=itemlist&task=category&id=.$cat->id:.$cat->alias";
						} else {
							$item->link = null;
						}
					}
				
				} else {
					$item->link = "index.php?option=com_k2&view=itemlist&task=category&id=.$cat->id:.$cat->alias";
				}
				
				// Parent category
				if($cat->parent) {
					$parent_cat = self::get_parent($cat->parent);
					
					$parent_cat = $parent_cat[0];
					$item->category = $parent_cat->name;
					$item->category_alias = $parent_cat->alias; 
				} else {
					$item->category = $cat->name;
					$item->category_alias = $cat->alias;
				}
				
				// Tags that should be nulled
				$item->date = false;
				$item->created= false;
				$item->featured = 0;
				$item->newlink = 0;
				$item->text = false;
				//$item->$id = false;
				$item->video =false;
				$item->authorLink=false;
				$item->author=false;
				$item->avatar=false;
				$item->tagblock=false;
				$item->tags=false;
				$item->rating="";
				$item->fulltext = false;
				
				// Add all items to an array
				$items[] = $item;
			}
			
			return $items;
		}
	}
	
	public static function get_parent($parent_id) {
		$db = JFactory::getDbo(); 
		$query = $db->getQuery(true); 
		$query->select(array('name', 'alias')) 
		      ->from($db->quoteName('#__k2_categories')) 
		      ->setLimit(1)
			  ->where($db->quoteName('id') . ' = '. $parent_id);
		$db->setQuery($query); 
		$rows = $db->loadObjectList();
		return $rows;
	}

}
